%define         hpsrcname       Healpix
%define         hpsrctime       2016Aug26
%define         srcname         %{hpsrcname}_%{version}_%{hpsrctime}

%define         majornum        0
%define         cmajornum       0
%define         cxxmajornum     0

%define         cname           c%{name}
%define         cxxname         %{name}_cxx

%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d
%define         libcname        %mklibname %{cname} %{cmajornum}
%define         develcname      %mklibname %{cname} -d
%define         libcxxname      %mklibname %{cxxname} %{cxxmajornum}
%define         develcxxname    %mklibname %{cxxname} -d
%define         gnudlname       gnudl-%{name}

%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | %__grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}/finclude
%define         gnudldir        %{_datadir}/gnudatalanguage
%define         gnudllibdir     %{gnudldir}/lib

Name:           healpix
Version:        3.31
Release:        %mkrel 2
Summary:        Hierarchical Equal Area isoLatitude Pixelation of a sphere
License:        GPLv2+
Group:          Sciences/Astronomy

URL:            http://healpix.sourceforge.net
Source0:        http://downloads.sourceforge.net/project/healpix/Healpix_%{version}/%{srcname}.tar.gz
Source1:        Makefile_f
Source2:        HEALPIX_startup.gdl
Source3:        idl_default_previewer.pro
Source4:        README_healpix.gdl


BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel


%description
HEALPix is a set of scientific tools implementing the Hierarchical Equal
Area isoLatitude Pixelation of a sphere. As suggested in the name,
this pixelation produces a subdivision of a spherical surface in which
each pixel covers the same surface area as every other pixel. HEALPix
provides various programs and libraries in C, C++, Fortran and
GDL/IDL which facilitate discretization of functions on a sphere at
sufficiently high resolution. It is the state-of-the-art program used
in Astronomy and Cosmology to deal with massive full-sky data sets.


%package -n %{libname}
License:        GPLv2+
Summary:        The HEALPix Fortran libraries
Group:          System/Libraries

%description -n %{libname}
%{summary}.


%package -n %{develname}
License:        GPLv2+
Summary:        Headers and modules for the Fortran HEALPix libraries
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
%{summary}.


%package -n %{libcname}
License:        GPLv2+
Summary:        The HEALPix C libraries
Group:          System/Libraries

%description -n %{libcname}
%{summary}.


%package -n %{develcname}
License:        GPLv2+
Summary:        Headers and development files for the C HEALPix libraries
Group:          Development/C
Provides:       healpix-C-devel = %{version}-%{release}
Provides:       %{cname}-devel = %{version}-%{release}
Provides:       lib%{cname}-devel = %{version}-%{release}
Requires:       %{libcname} = %{version}-%{release}

%description -n %{develcname}
%{summary}.



%package -n %{libcxxname}
License:        GPLv2+
Summary:        The HEALPix C++ libraries
Group:          System/Libraries

%description -n %{libcxxname}
%{summary}.


%package -n %{develcxxname}
License:        GPLv2+
Summary:        Headers and development files for the C++ HEALPix libraries
Group:          Development/C++
Provides:       healpix-c++-devel = %{version}-%{release}
Provides:       %{cxxname}-devel = %{version}-%{release}
Provides:       lib%{cxxname}-devel = %{version}-%{release}
Requires:       %{libcxxname} = %{version}-%{release}

%description -n %{develcxxname}
%{summary}.



%package -n %{gnudlname}
License:        BSD
Summary:        HEALPix GDL/IDL routines for the GNU data language
Group:          Sciences/Astronomy
Provides:       gdl-healpix = %{version}-%{release}
Provides:       gdl-healpix-astron = %{version}-%{release}
Requires:       gnudl
Requires:       imagemagick
Requires:       gv
Requires:       ghostscript

%description -n %{gnudlname}
HEALPix support for the GNU data language. This package provides
IDL/GDL routines to project any data in HEALPIX tessellation, create
maps, make nice plots, and perform various input/output operations
using the FITS format. For an automatic loading of the HEALPix
routines, check the README file located in the %{_docdir}/%{gnudlname}
directory.



%prep

%setup -q -n %{hpsrcname}_%{version}


%__cp %{SOURCE1} Makefile
%__mkdir binf libf includef
pushd libf
%__ln_s libhealpix.so.%{majornum} libhealpix.so
%__ln_s libhpxgif.so.%{majornum} libhpxgif.so
%__ln_s libsharp_healpix_f.so.%{majornum} libsharp_healpix_f.so
popd
%__cp %{SOURCE4} README_healpix.gdl



%build

#C libraries and binaries
pushd src/C/autotools
autoreconf -fi 
%configure2_5x --enable-static=no
%make
popd

#C++ libs
pushd src/cxx/autotools
autoreconf -fi
%configure2_5x --enable-static=no
%make
popd

#fortran libraries + binaries + modules
%__make F90_FFLAGS="%{optflags} -DGFORTRAN  \
      -fopenmp -fPIC " SHLIB_SUFFIX=".so.%{majornum}" \
      F90_CFLAGS="%{optflags} -std=c99 -DgFortran -fopenmp -fPIC "


%install

#C
pushd src/C/autotools
%makeinstall_std
popd

#C++
pushd src/cxx/autotools
%makeinstall_std
popd

#Fortran
pushd binf
%__install -d %{buildroot}%{_bindir}
%__install -D -m 755 alteralm %{buildroot}%{_bindir}
%__install -D -m 755 anafast %{buildroot}%{_bindir}
%__install -D -m 755 hotspot %{buildroot}%{_bindir}
%__install -D -m 755 map2gif %{buildroot}%{_bindir}
%__install -D -m 755 median_filter %{buildroot}%{_bindir}
%__install -D -m 755 plmgen %{buildroot}%{_bindir}
%__install -D -m 755 process_mask %{buildroot}%{_bindir}
%__install -D -m 755 sky_ng_sim* %{buildroot}%{_bindir}
%__install -D -m 755 smoothing %{buildroot}%{_bindir}
%__install -D -m 755 synfast %{buildroot}%{_bindir}
%__install -D -m 755 ud_grade %{buildroot}%{_bindir}
popd

pushd libf
%__install -d %{buildroot}%{_libdir}
%__install -D -m 755 libhealpix.so.%{majornum} %{buildroot}%{_libdir}
%__install -D -m 755 libhpxgif.so.%{majornum} %{buildroot}%{_libdir}
%__install -D -m 755 libsharp_healpix_f.so.%{majornum} %{buildroot}%{_libdir}
popd
pushd %{buildroot}%{_libdir}
%__ln_s libhealpix.so.%{majornum} libhealpix.so
%__ln_s libhpxgif.so.%{majornum} libhpxgif.so
%__ln_s libsharp_healpix_f.so.%{majornum} libsharp_healpix_f.so
popd

pushd includef
%__install -d %{buildroot}/%{fincludedir}/healpix
%__install -D -m 644 *.mod %{buildroot}/%{fincludedir}/healpix
popd


#GDL
%__install -D -m 644 %{SOURCE2} %{buildroot}%gnudldir/HEALPIX_startup.gdl

pushd src/idl

%__install -d %{buildroot}/%gnudllibdir/healpix
%__install -D -m 644 %{SOURCE3} %{buildroot}%gnudllibdir/healpix

%__install -d %{buildroot}/%gnudllibdir/healpix/examples
pushd examples
%__install -D -m 644 coadd_raw_obs.pro %{buildroot}%gnudllibdir/healpix/examples
%__install -D -m 644 raw_obs.txt %{buildroot}%gnudllibdir/healpix/examples
popd

pushd fits
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd interfaces
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd misc
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd toolkit
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd visu
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd zzz_external
%__install -D -m 644 README %{buildroot}%gnudllibdir/healpix/README.external
popd

%__install -d %{buildroot}%gnudllibdir/healpix/astron
pushd zzz_external/astron
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/astron
popd

%__install -d %{buildroot}%gnudllibdir/healpix/cgis
pushd zzz_external/cgis
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/cgis
popd

%__install -d %{buildroot}%gnudllibdir/healpix/obsolete_astron
pushd zzz_external/obsolete_astron
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/obsolete_astron
popd

popd

#nuke la files from libtools
find %{buildroot}%{_libdir} -name *.la -delete
#should not be installed
%__rm %{buildroot}%{_includedir}/%{cxxname}/sharp_geomhelpers.c


%files
%doc COPYING READ_Copyrights_Licenses.txt test
%{_bindir}/alteralm
%{_bindir}/anafast
%{_bindir}/hotspot
%{_bindir}/map2gif
%{_bindir}/median_filter
%{_bindir}/plmgen
%{_bindir}/process_mask
%{_bindir}/sky_ng_sim
%{_bindir}/sky_ng_sim_bin
%{_bindir}/smoothing
%{_bindir}/synfast
%{_bindir}/ud_grade
%{_bindir}/anafast_cxx
%{_bindir}/alm2map_cxx
%{_bindir}/calc_powspec
%{_bindir}/hotspots_cxx
%{_bindir}/map2tga
%{_bindir}/median_filter_cxx
%{_bindir}/mult_alm
%{_bindir}/rotalm_cxx
%{_bindir}/udgrade_harmonic_cxx
%{_bindir}/udgrade_cxx
%{_bindir}/smoothing_cxx
%{_bindir}/syn_alm_cxx



%files -n %{libname}
%{_libdir}/libhealpix.so.%{majornum}
%{_libdir}/libhpxgif.so.%{majornum}
%{_libdir}/libsharp_healpix_f.so.%{majornum}



%files -n %{develname}
%{_libdir}/libhealpix.so
%{_libdir}/libhpxgif.so
%{_libdir}/libsharp_healpix_f.so
%dir %{fincludedir}/healpix
%{fincludedir}/healpix/*.mod



%files -n %{libcname}
%{_libdir}/libchealpix.so.%{cmajornum}
%{_libdir}/libchealpix.so.%{cmajornum}.*



%files -n %{develcname}
%doc src/C/CHANGES
%{_includedir}/chealpix.h
%{_libdir}/libchealpix.so
%{_libdir}/pkgconfig/chealpix.pc



%files -n %{libcxxname}
%{_libdir}/libhealpix_cxx.so.%{cxxmajornum}
%{_libdir}/libhealpix_cxx.so.%{cxxmajornum}.*



%files -n %{develcxxname}
%doc src/cxx/CHANGES
%dir %{_includedir}/%{cxxname}
%{_includedir}/%{cxxname}/*.h
%{_libdir}/libhealpix_cxx.so
%{_libdir}/pkgconfig/healpix_cxx.pc




%files -n %{gnudlname}
%doc README_healpix.gdl src/idl/README.txt
%{gnudldir}/HEALPIX_startup.gdl
%dir %{gnudllibdir}/healpix
%dir %{gnudllibdir}/healpix/examples
%dir %{gnudllibdir}/healpix/astron
%dir %{gnudllibdir}/healpix/cgis
%dir %{gnudllibdir}/healpix/obsolete_astron
%{gnudllibdir}/healpix/README.external
%{gnudllibdir}/healpix/*.pro
%{gnudllibdir}/healpix/examples/*.pro
%{gnudllibdir}/healpix/examples/*.txt
%{gnudllibdir}/healpix/astron/*.pro
%{gnudllibdir}/healpix/cgis/*.pro
%{gnudllibdir}/healpix/obsolete_astron/*.pro




%changelog
* Tue Nov 22 2016 eatdirt <eatdirt> 3.31-2.mga6
+ Revision: 1068787
- Rebuild for new cfitsio

* Sun Aug 28 2016 eatdirt <eatdirt> 3.31-1.mga6
+ Revision: 1049350
- Update to bug fix release 3.31

* Thu Aug 04 2016 eatdirt <eatdirt> 3.30-5.mga6
+ Revision: 1044455
- Rebuild for new gfortran version (fortran modules)

* Wed Mar 09 2016 eatdirt <eatdirt> 3.30-4.mga6
+ Revision: 988543
- Adding ifarch for arm compat

* Wed Mar 09 2016 eatdirt <eatdirt> 3.30-3.mga6
+ Revision: 988541
- Rebuild for new cfitsio

* Fri Feb 19 2016 umeabot <umeabot> 3.30-2.mga6
+ Revision: 970627
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 eatdirt <eatdirt> 3.30-1.mga6
+ Revision: 887423
- Upgrade to version 3.30

* Fri Dec 05 2014 eatdirt <eatdirt> 3.20-1.mga5
+ Revision: 801610
- Upgrade to official 3.20 Dec05 version
- Upgrading to latest stable version 3.20

* Wed Oct 15 2014 umeabot <umeabot> 3.12-0.20140702svn581.8.mga5
+ Revision: 747163
- Second Mageia 5 Mass Rebuild

* Thu Sep 25 2014 eatdirt <eatdirt> 3.12-0.20140702svn581.7.mga5
+ Revision: 724632
- Fix missing soname

* Tue Sep 16 2014 umeabot <umeabot> 3.12-0.20140702svn581.6.mga5
+ Revision: 680102
- Mageia 5 Mass Rebuild

* Wed Jul 02 2014 eatdirt <eatdirt> 3.12-0.20140702svn581.5.mga5
+ Revision: 642199
- Update with latest pre-release svn581

* Thu Mar 27 2014 eatdirt <eatdirt> 3.12-0.20140327svn572.4.mga5
+ Revision: 609032
- Upgrade to latest svn, upstream fix of missing soname

* Fri Feb 28 2014 eatdirt <eatdirt> 3.12-0.20140227svn564.3.mga5
+ Revision: 597719
- Rebuild for new cfitsio

* Thu Feb 27 2014 eatdirt <eatdirt> 3.12-0.20140227svn564.2.mga5
+ Revision: 597646
- Fixing wrong soname, updating to last svn

* Tue Feb 25 2014 eatdirt <eatdirt> 3.12-0.20140225svn560.1.mga5
+ Revision: 597207
- Upgrade to latest svn snapshot

* Tue Oct 22 2013 umeabot <umeabot> 3.11-5.mga4
+ Revision: 542675
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 3.11-4.mga4
+ Revision: 497783
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 eatdirt <eatdirt> 3.11-3.mga4
+ Revision: 491615
- Fix URL, including pyc/pyo files

* Fri Aug 16 2013 eatdirt <eatdirt> 3.11-2.mga4
+ Revision: 466804
- Fixing misprints in descriptions

* Thu Aug 15 2013 eatdirt <eatdirt> 3.11-1.mga4
+ Revision: 466772
- Fixing Makefile for parallel build
- Adding documentation files
- imported package healpix

